get_config()
Get the global configuration instance.
Usage
get_config()Creates a new Config instance on first call, then returns the same instance on subsequent calls.
Returns
Config- Config instance.
Get the global configuration instance.
Usage
Creates a new Config instance on first call, then returns the same instance on subsequent calls.
Config