get_logger()
Get a logger for the given module name.
Usage
get_logger(name)This is the preferred way to obtain a logger in smartclass modules. The logger will be a child of the ‘smartclass’ logger, inheriting its configuration.
Parameters
name: str- Module name (typically name).
Returns
logging.Logger- Example: >>> from smartclass.logging import get_logger >>> logger = get_logger(name) >>> logger.info(“Processing started”)